==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/SummaryChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryChangedEventArgsDescription } from "./SummaryChangedEventArgsDescription";
/**
 * @hidden
 */
var SummaryChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SummaryChangedEventArgsDescriptionMetadata, _super);
    function SummaryChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SummaryChangedEventArgsDescriptionMetadata.a == null) {
            SummaryChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryChangedEventArgsDescriptionMetadata.c(SummaryChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(SummaryChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(SummaryChangedEventArgsDescriptionMetadata.a);
    };
    SummaryChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("ID", "String");
        a.item("IsEnabled", "Boolean");
    };
    SummaryChangedEventArgsDescriptionMetadata.d = function (a) {
        SummaryChangedEventArgsDescriptionMetadata.b(a);
        a.u("SummaryChangedEventArgs", function () { return new SummaryChangedEventArgsDescription(); });
        a.t("SummaryChangedEventArgs", SummaryChangedEventArgsDescriptionMetadata.a);
    };
    SummaryChangedEventArgsDescriptionMetadata.$t = markType(SummaryChangedEventArgsDescriptionMetadata, 'SummaryChangedEventArgsDescriptionMetadata');
    SummaryChangedEventArgsDescriptionMetadata.a = null;
    return SummaryChangedEventArgsDescriptionMetadata;
}(Base));
export { SummaryChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SummaryChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryChangedEventArgsDescription } from "./SummaryChangedEventArgsDescription";
/**
 * @hidden
 */
var SummaryChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SummaryChangedEventArgsDescriptionMetadata, _super);
    function SummaryChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SummaryChangedEventArgsDescriptionMetadata.a == null) {
            SummaryChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryChangedEventArgsDescriptionMetadata.c(SummaryChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(SummaryChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(SummaryChangedEventArgsDescriptionMetadata.a);
    };
    SummaryChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("ID", "String");
        a.item("IsEnabled", "Boolean");
    };
    SummaryChangedEventArgsDescriptionMetadata.d = function (a) {
        SummaryChangedEventArgsDescriptionMetadata.b(a);
        a.aa("SummaryChangedEventArgs", function () { return new SummaryChangedEventArgsDescription(); });
        a.z("SummaryChangedEventArgs", SummaryChangedEventArgsDescriptionMetadata.a);
    };
    SummaryChangedEventArgsDescriptionMetadata.$t = markType(SummaryChangedEventArgsDescriptionMetadata, 'SummaryChangedEventArgsDescriptionMetadata');
    SummaryChangedEventArgsDescriptionMetadata.a = null;
    return SummaryChangedEventArgsDescriptionMetadata;
}(Base));
export { SummaryChangedEventArgsDescriptionMetadata };
